==> org.eclipse.tracecompass.lttng2.control.ui.source_1.1.0.201602091005.jar: org/eclipse/tracecompass/internal/lttng2/control/ui/views/dialogs/IEnableUstEvents.java <==
/**********************************************************************
 * Copyright (c) 2012, 2014 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License v1.0 which
 * accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *   Bernd Hufmann - Updated for support of LTTng Tools 2.1
 **********************************************************************/
package org.eclipse.tracecompass.internal.lttng2.control.ui.views.dialogs;

import java.util.List;

import org.eclipse.tracecompass.internal.lttng2.control.core.model.LogLevelType;
import org.eclipse.tracecompass.internal.lttng2.control.core.model.TraceLogLevel;

/**
 * <p>
 * Interface for providing information about UST events to be enabled.
 * </p>
 *
 * @author Bernd Hufmann
 */
public interface IEnableUstEvents {

    // ------------------------------------------------------------------------
    // Accessors
    // ------------------------------------------------------------------------

    /**
     * @return a flag whether the tracepoints shall be configured.
     */
    boolean isTracepoints();

    /**
     * @return a flag indicating whether all tracepoints shall be enabled or not.
     */
    boolean isAllTracePoints();

    /**
     * @return a list of event names to be enabled.
     */
    List<String> getEventNames();

    /**
     * @return a flag whether events using wildcards should be enabled
     */
    boolean isWildcard();

    /**
     * @return a wildcard
     */
    String getWildcard();

    /**
     * @return a flag whether events using log levels should be enabled
     */
    boolean isLogLevel();

    /**
     * @return a log level type (loglevel or loglevel-only)
     */
    LogLevelType getLogLevelType();

    /**
     * @return a log level
     */
    TraceLogLevel getLogLevel();

    /**
     * @return a event name for the log level enable action
     */
    String getLogLevelEventName();

    /**
     * @return a filter expression
     */
    String getFilterExpression();

}

==> org.eclipse.tracecompass.lttng2.control.ui.source_1.4.1.202510291437.jar: org/eclipse/tracecompass/internal/lttng2/control/ui/views/dialogs/IEnableUstEvents.java <==
/**********************************************************************
 * Copyright (c) 2012, 2014 Ericsson
 *
 * All rights reserved. This program and the accompanying materials are
 * made available under the terms of the Eclipse Public License 2.0 which
 * accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Bernd Hufmann - Initial API and implementation
 *   Bernd Hufmann - Updated for support of LTTng Tools 2.1
 **********************************************************************/
package org.eclipse.tracecompass.internal.lttng2.control.ui.views.dialogs;

import java.util.List;

/**
 * Interface for providing information about UST events to be enabled.
 *
 * @author Bernd Hufmann
 */
public interface IEnableUstEvents  extends IBaseEnableUstEvents {

    // ------------------------------------------------------------------------
    // Accessors
    // ------------------------------------------------------------------------

    /**
     * @return a flag whether the tracepoints shall be configured.
     */
    boolean isTracepoints();

    /**
     * @return a flag whether events using wildcards should be enabled
     */
    boolean isWildcard();

    /**
     * @return a wildcard
     */
    String getWildcard();

    /**
     * @return a filter expression
     */
    String getFilterExpression();

    /**
     * @return a list of events to exclude
     */
    List<String> getExcludedEvents();

}
